Document

Struct Document 

pub struct Document {
    pub doc: PdfDocument,
    pub title_font: PdfFontHandle,
    pub code_font: PdfFontHandle,
    pub page_size: PageSize,
    pub title: String,
    /* private fields */
}
Container for all the data required to insert elements into the PDF

Fields

doc: PdfDocument

The printpdf PDF document

title_font: PdfFontHandle

The medium weight font handle

code_font: PdfFontHandle

The regular weight font handle

page_size: PageSize

Page size

title: String

Document title

Implementations

Source

impl Document

pub fn new( title: String, page_size: PageSize, ) -> Result<Document, Box<dyn Error>>

Initialize the PDF with default dimensions and the required fonts. Also sets the title and the producer in the PDF metadata.

pub fn insert_title_text(&mut self, title: String)

Insert the given title at the top of the PDF

pub fn insert_pem_text(&mut self, pem: String)

Insert the given PEM ciphertext in the bottom half of the page

pub fn insert_qr_code(&mut self, text: String) -> Result<(), Box<dyn Error>>

Insert the QR code of the PEM encoded ciphertext in the top half of the page

pub fn draw_grid(&mut self)

Draw a grid debugging layout issues

pub fn draw_line( &mut self, points: Vec<Point>, thickness: f32, dash_pattern: LineDashPattern, )

Draw a line on the page

pub fn insert_notes_field(&mut self, label: String, skip_line: bool)

Insert the notes field label and placeholder in the PDF

Add the footer at the bottom of the page

pub fn save_to_bytes(self) -> Result<Vec<u8>, Box<dyn Error>>

Build the final PDF and return as bytes

pub fn save_to_writer<W: Write>( self, writer: &mut W, ) -> Result<(), Box<dyn Error>>

Build the final PDF and write to a writer

pub fn create_pdf( self, grid: bool, notes_label: String, skip_notes_line: bool, encrypted: String, ) -> Result<Vec<u8>, Box<dyn Error>>

Build a PaperAge PDF and return its bytes.

Arguments
  • grid - Whether to draw a debug grid
  • notes_label - Label for the notes/passphrase field
  • skip_notes_line - Whether to omit the notes placeholder line
  • encrypted - The encrypted ciphertext to encode as a QR code and PEM block